California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 28 - 2000 REPEAL OF ADDITIONAL TOBACCO SURTAX ENACTED BY PROPOSITION 10. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992302 | STOP BIG TOBACCO - NO ON PROP 28, SPONSORED BY THE AMERICAN CANCER SOCIETY, AMERICAN LUNG ASSOCIATION, AMERICAN HEART ASSOCIATION AND THE CAMPAIGN FOR TOBACCO-FREE-KIDS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992252 | YES ON PROPOSITION 28 COMMITTEE, SPONSORED BY CALIFORNIA ASSOCIATION OF RETAIL TOBACCONISTS, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
971785 | COALITION TO SAVE PROP 10, A PROJECT OF FORUM FOR EARLY CHILDHOOD DEVELOPMENT, NO ON PROP 28 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990352 | CIGARETTES CHEAPER! COMMITTEE TO PASS PROPOSITION 28 | SUPPORT